import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { C as CustomField, G as GetCustomFieldResponse, L as ListCustomFieldsOptions, a as ListCustomFieldsResponse, U as UpdateCustomField, b as UpdateCustomFieldsOrderOptions, c as UpdateCustomFieldsOrderResponse } from './members-v1-custom-field-custom-fields.universal-B3dgTXBK.js';
export { ae as ActionEvent, A as AppliesTo, w as Asset, g as CreateCustomFieldRequest, h as CreateCustomFieldResponse, q as DefaultPrivacyChanged, B as DeleteContext, r as DeleteCustomFieldRequest, s as DeleteCustomFieldResponse, D as DeleteStatus, a8 as DomainEvent, a9 as DomainEventBodyOneOf, a7 as Empty, aa as EntityCreatedEvent, ad as EntityDeletedEvent, ac as EntityUpdatedEvent, k as GetCustomFieldRequest, H as HideCustomFieldRequest, t as HideCustomFieldResponse, ag as IdentificationData, ah as IdentificationDataIdOneOf, I as IncorrectFieldTypeData, i as IncorrectPrivacyData, j as InvalidSocialTypeData, l as ListCustomFieldsRequest, af as MessageEnvelope, M as MetaSiteSpecialEvent, v as MetaSiteSpecialEventPayloadOneOf, N as Namespace, _ as NamespaceChanged, a3 as OdeditorAssigned, a4 as OdeditorUnassigned, O as Origin, m as Paging, n as PagingMetadata, a5 as PicassoAssigned, a6 as PicassoUnassigned, P as Privacy, R as ReservedFieldNameNonEditable, ab as RestoreInfo, d as Section, V as ServiceProvisioned, X as ServiceRemoved, x as SiteCreated, f as SiteCreatedContext, z as SiteDeleted, Z as SiteHardDeleted, K as SiteMarkedAsTemplate, Q as SiteMarkedAsWixSite, F as SitePublished, a2 as SitePurgedExternally, Y as SiteRenamed, y as SiteTransferred, E as SiteUndeleted, J as SiteUnpublished, a1 as SiteUrlChanged, S as SocialTypeType, e as State, $ as StudioAssigned, a0 as StudioUnassigned, T as Type, o as UpdateCustomFieldRequest, p as UpdateCustomFieldResponse, u as UpdateCustomFieldsOrderRequest, W as WebhookIdentityType } from './members-v1-custom-field-custom-fields.universal-B3dgTXBK.js';

declare function createCustomField$1(httpClient: HttpClient): CreateCustomFieldSignature;
interface CreateCustomFieldSignature {
    /**
     * Creates a custom field.
     * @param - Custom field to create.
     * @returns Created custom field.
     */
    (field: CustomField): Promise<CustomField>;
}
declare function getCustomField$1(httpClient: HttpClient): GetCustomFieldSignature;
interface GetCustomFieldSignature {
    /**
     * Retrieves a custom field by ID.
     * @param - Custom field ID.
     */
    (_id: string): Promise<GetCustomFieldResponse>;
}
declare function listCustomFields$1(httpClient: HttpClient): ListCustomFieldsSignature;
interface ListCustomFieldsSignature {
    /**
     * Retrieves a list of custom fields and fields provided by Members Area, given the provided paging.
     *
     * The fields are ordered by section in the following sequence:
     * - `GENERAL`
     * - `DISPLAY_INFO`
     * - `SOCIAL`
     *
     * The fields in the same section are ordered by the field creation date.
     *
     * To change the order of fields in sections, call Update Custom Fields Order.
     */
    (options?: ListCustomFieldsOptions | undefined): Promise<ListCustomFieldsResponse>;
}
declare function updateCustomField$1(httpClient: HttpClient): UpdateCustomFieldSignature;
interface UpdateCustomFieldSignature {
    /**
     * Updates a custom field.
     *
     * For custom fields you can update the following fields: `name`, `defaultPrivacy`, and `socialType`.
     *
     * For system fields you can only update the `defaultPrivacy` field.
     * @param - Custom field ID.
     * @returns Updated custom field.
     */
    (_id: string, field: UpdateCustomField): Promise<CustomField>;
}
declare function deleteCustomField$1(httpClient: HttpClient): DeleteCustomFieldSignature;
interface DeleteCustomFieldSignature {
    /**
     * Deletes a custom field and removes the corresponding column from the [Contact List](https://support.wix.com/en/article/wix-contacts-managing-your-contact-list)
     * display. The custom field is no longer suggested when adding custom fields.
     * @param - ID of the custom field to delete.
     * @param - Revision number.
     */
    (_id: string, revision: string): Promise<void>;
}
declare function hideCustomField$1(httpClient: HttpClient): HideCustomFieldSignature;
interface HideCustomFieldSignature {
    /**
     * Hides a custom field from the custom fields list, yet it's still available as a suggested field
     * ([SDK](https://dev.wix.com/docs/sdk/backend-modules/members/custom-field-suggestions/introduction) | [REST](https://dev.wix.com/docs/rest/crm/members-contacts/members/custom-fields/custom-field-suggestions/introduction))
     * to add later.
     *
     * The related contacts custom field will still be available in the [Contact List](https://support.wix.com/en/article/wix-contacts-managing-your-contact-list).
     * @param - ID of the custom field to hide.
     * @param - Revision number.
     */
    (_id: string, revision: string): Promise<void>;
}
declare function updateCustomFieldsOrder$1(httpClient: HttpClient): UpdateCustomFieldsOrderSignature;
interface UpdateCustomFieldsOrderSignature {
    /**
     * Updates the order of custom fields in a section.
     * @param - IDs of the custom fields to be reordered.
     */
    (fieldIds: string[], options?: UpdateCustomFieldsOrderOptions | undefined): Promise<UpdateCustomFieldsOrderResponse>;
}

declare const createCustomField: MaybeContext<BuildRESTFunction<typeof createCustomField$1> & typeof createCustomField$1>;
declare const getCustomField: MaybeContext<BuildRESTFunction<typeof getCustomField$1> & typeof getCustomField$1>;
declare const listCustomFields: MaybeContext<BuildRESTFunction<typeof listCustomFields$1> & typeof listCustomFields$1>;
declare const updateCustomField: MaybeContext<BuildRESTFunction<typeof updateCustomField$1> & typeof updateCustomField$1>;
declare const deleteCustomField: MaybeContext<BuildRESTFunction<typeof deleteCustomField$1> & typeof deleteCustomField$1>;
declare const hideCustomField: MaybeContext<BuildRESTFunction<typeof hideCustomField$1> & typeof hideCustomField$1>;
declare const updateCustomFieldsOrder: MaybeContext<BuildRESTFunction<typeof updateCustomFieldsOrder$1> & typeof updateCustomFieldsOrder$1>;

export { CustomField, GetCustomFieldResponse, ListCustomFieldsOptions, ListCustomFieldsResponse, UpdateCustomField, UpdateCustomFieldsOrderOptions, UpdateCustomFieldsOrderResponse, createCustomField, deleteCustomField, getCustomField, hideCustomField, listCustomFields, updateCustomField, updateCustomFieldsOrder };
